pm4py.algo.discovery.temporal\_profile package
==============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.discovery.temporal_profile.variants

Submodules
----------

pm4py.algo.discovery.temporal\_profile.algorithm module
-------------------------------------------------------

.. automodule:: pm4py.algo.discovery.temporal_profile.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.temporal_profile
   :members:
   :undoc-members:
   :show-inheritance:
